shapes = {'Beta';'Gamma';'Gaussian'; 'Inverse gamma -- 1'; 'Uniform'; 'Inverse gamma -- 2'; NaN; 'Weibull'};

o0 = load('resultswithoutricattifixedpoint.mat');
o1 = load('resultswithricattifixedpoint.mat');

pnames = o0.bayestopt_.name;
shapes = shapes(o0.bayestopt_.pshape);

fid = fopen('estimation-results.tex', 'w');
fprintf(fid, '\\documentclass{article}\n');
skipline(1, fid)
fprintf(fid, '\\usepackage{longtable,booktabs,dcolumn,geometry,changepage,nopageno}\n');
skipline(1, fid)
fprintf(fid, '\\newcolumntype{d}[1]{D{.}{.}{#1}}\n');
fprintf(fid, '\\begin{document}\n');
skipline(1, fid)
fprintf(fid, '\\begin{adjustwidth}{-6cm}{}\n');
fprintf(fid, '\\begin{longtable}[l]{ l  l  d{4}  d{4}  d{4}  d{4}  d{4}  d{4} }\n');
fprintf(fid, '\\toprule\n');
fprintf(fid, '\\multicolumn{1}{c}{} & \\multicolumn{3}{c}{\\textbf{Prior}} & \\multicolumn{2}{c}{\\textbf{Posterior with $P^{\\star}$}} & \\multicolumn{2}{c}{\\textbf{Posterior with $\\bar P$}}\\\\\n');
fprintf(fid, '\\cmidrule(rl){2-4}\n');
fprintf(fid, '\\cmidrule(rl){5-6}\n');
fprintf(fid, '\\cmidrule(rl){7-8}\n');
fprintf(fid, '\\textbf{Parameters} & Shape & \\multicolumn{1}{c}{Mode} & \\multicolumn{1}{c}{SD} & \\multicolumn{1}{c}{Mode} & \\multicolumn{1}{c}{SD} & \\multicolumn{1}{c}{Mode} & \\multicolumn{1}{c}{SD}  \\\\\n');
fprintf(fid, '\\midrule\n');
fprintf(fid, '\\endhead\n');
skipline(1, fid)
fprintf(fid, '\\\\\n');
fprintf(fid, '\\midrule\n');
fprintf(fid, '\\multicolumn{8}{c}{\\tiny{\\textbf{Continued on next page}}}\\\\\n');
fprintf(fid, '\\endfoot\n');
skipline(1, fid)
fprintf(fid, '\\bottomrule\n');
fprintf(fid, '\\\\\n');
fprintf(fid, '\\caption{\\textbf{Estimation results of Quest-III.} Without and with the fixed point of the Ricatti equation as an initial condition of the Kalman filter. Standard deviation estimates rely on the inverse of the Hessian matrix at the estimated posterior mode.}\n');
fprintf(fid, '\\endlastfoot\n');
skipline(1, fid)
for i=1:63
    fprintf(fid, '%s & %s & %.4f & %.4f & %.4f & %.4f & %.4f & %.4f\\\\\n', ...
            strrep(pnames{i}, '_', '\_'), ...
            shapes{i}, ...
            o0.bayestopt_.p5(i), o0.bayestopt_.p2(i), ...
            o0.oo_.posterior.optimization.mode(i), ...
            sqrt(o0.oo_.posterior.optimization.Variance(i,i)), ...
            o1.oo_.posterior.optimization.mode(i), ...
            sqrt(o1.oo_.posterior.optimization.Variance(i,i)));
end
skipline(1, fid)
fprintf(fid, '\\end{longtable}\n');
fprintf(fid, '\\end{adjustwidth}\n');
fprintf(fid, '\\end{document}\n');
fclose(fid);

!pdflatex estimation-results
!pdflatex estimation-results
